@@ -1,5 +1,5 @@
 from .errors import BaseError, RateError, AuthError
-from .const import FanModes, ActivityNames, SystemModes
+from .const import FanModes, ActivityNames, SystemModes, TemperatureUnits
 from .api_connection import ApiConnection
 from .config import Config, ConfigZone, ConfigZoneActivity
 from .profile import Profile
